@@ -187,7 +187,9 @@ class Scaler:
     #
 
     def _by_plane(
-        self, base: np.ndarray, func: Callable[[np.ndarray, int, int], np.ndarray],
+        self,
+        base: np.ndarray,
+        func: Callable[[np.ndarray, int, int], np.ndarray],
     ) -> np.ndarray:
         """Loop over 3 of the 5 dimensions and apply the func transform."""
         assert 5 == len(base.shape)
